# authentic2 - versatile identity manager
# Copyright (C) 2010-2020 Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import django.apps


class AppConfig(django.apps.AppConfig):

    name = 'authentic2_auth_saml'

    def ready(self):
        from django.db.models.signals import pre_save
        from authentic2.custom_user.models import DeletedUser

        pre_save.connect(
            self.pre_save_deleted_user,
            sender=DeletedUser)

    def pre_save_deleted_user(self, sender, instance, **kwargs):
        '''Delete and copy UserSamlIdentifier to old_data'''
        from mellon.models import UserSAMLIdentifier

        saml_accounts = UserSAMLIdentifier.objects.filter(user__uuid=instance.old_uuid).order_by('id')
        for saml_account in saml_accounts:
            instance.old_data = instance.old_data or {}
            instance.old_data.setdefault('saml_accounts', []).append({
                'issuer': saml_account.issuer,
                'name_id': saml_account.name_id,
            })
